@@ -51,9 +51,9 @@ class InitOralProcessRequest(AbstractModel):
         :type EvalMode: int
         :param ScoreCoeff: 评价苛刻指数。取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数。
 1.0：适用于最小年龄段用户，一般对应儿童应用场景；
-4.0：适用于最高年龄段用户，一般对应成人严格打分场景。
+4.0：适用于最高年龄段用户，一般对应成人严格打分场景。苛刻度影响范围参考：[苛刻度影响范围](https://cloud.tencent.com/document/product/884/78824#.E8.8B.9B.E5.88.BB.E5.BA.A6)
         :type ScoreCoeff: float
-        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
+        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。使用指南：[业务应用](https://cloud.tencent.com/document/product/884/78824#.E4.B8.9A.E5.8A.A1.E5.BA.94.E7.94.A8)
         :type SoeAppId: str
         :param IsLongLifeSession: 长效session标识，当该参数为1时，session的持续时间为300s，但会一定程度上影响第一个数据包的返回速度，且TransmitOralProcess必须同时为1才可生效。
         :type IsLongLifeSession: int
@@ -66,9 +66,8 @@ class InitOralProcessRequest(AbstractModel):
 可以在评估过程中的分片传输请求中，返回已经评估断句的中间结果，中间结果可用于客户端 UI 更新，输出结果为TransmitOralProcess请求返回结果 SentenceInfoSet 字段。
         :type SentenceInfoEnabled: int
         :param ServerType: 评估语言
-0：英文
+0：英文（默认）
 1：中文
-ServerType不填默认为0
         :type ServerType: int
         :param IsAsync: 异步模式标识
 0：同步模式
@@ -78,8 +77,9 @@ ServerType不填默认为0
         :param TextMode: 输入文本模式
 0: 普通文本
 1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本
-2：音素注册模式（提工单注册需要使用音素的单词）。
         :type TextMode: int
+        :param Keyword: 主题词和关键词
+        :type Keyword: str
         """
         self.SessionId = None
         self.RefText = None
@@ -93,6 +93,7 @@ ServerType不填默认为0
         self.ServerType = None
         self.IsAsync = None
         self.TextMode = None
+        self.Keyword = None
 
 
     def _deserialize(self, params):
@@ -108,6 +109,7 @@ ServerType不填默认为0
         self.ServerType = params.get("ServerType")
         self.IsAsync = params.get("IsAsync")
         self.TextMode = params.get("TextMode")
+        self.Keyword = params.get("Keyword")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -145,14 +147,14 @@ class Keyword(AbstractModel):
 
     def __init__(self):
         r"""
-        :param RefText: 被评估语音对应的文本，句子模式下不超过个 20 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。如需要在单词模式和句子模式下使用自定义音素，可以通过设置 TextMode 使用[音素标注](https://cloud.tencent.com/document/product/884/33698)。
+        :param RefText: 被评估语音对应的文本，句子模式下不超过 20个单词或者中文文字，段落模式不超过 120个单词或者中文文字，中文文字需使用 utf-8 编码，自由说模式RefText可以不填。如需要在单词模式和句子模式下使用自定义音素，可以通过设置 TextMode 使用[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
         :param EvalMode: 评估模式，0：词模式（中文评测模式下为文字模式），1：句子模式，2：段落模式，3：自由说模式，当为词模式评估时，能够提供每个音节的评估信息，当为句子模式时，能够提供完整度和流利度信息。
         :type EvalMode: int
         :param ScoreCoeff: 评价苛刻指数，取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数，1.0为小年龄段，4.0为最高年龄段
         :type ScoreCoeff: float
         :param ServerType: 评估语言，0：英文，1：中文。
-ServerType不填默认传0
+ServerType不填默认为0
         :type ServerType: int
         :param TextMode: 输入文本模式，0: 普通文本，1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本。
         :type TextMode: int
@@ -186,28 +188,30 @@ class KeywordEvaluateRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param SeqId: 流式数据包的序号，从1开始，当IsEnd字段为1后后续序号无意义，当IsLongLifeSession不为1且为非流式模式时无意义。
+        :param SeqId: 流式数据包的序号，从1开始，当IsEnd字段为1后后续序号无意义，非流式模式时无意义。
 注意：序号上限为3000，不能超过上限。
         :type SeqId: int
         :param IsEnd: 是否传输完毕标志，若为0表示未完毕，若为1则传输完毕开始评估，非流式模式下无意义。
         :type IsEnd: int
         :param VoiceFileType: 语音文件类型
-1: raw
+1: raw/pcm
 2: wav
 3: mp3
 4: speex
-语音文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败。
+[音频上传格式](https://cloud.tencent.com/document/product/884/56132)
         :type VoiceFileType: int
         :param VoiceEncodeType: 语音编码类型
 1:pcm
         :type VoiceEncodeType: int
-        :param UserVoiceData: 当前数据包数据, 流式模式下数据包大小可以按需设置，在网络良好的情况下，建议设置为1k，且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数），编码格式要求为BASE64。
+        :param UserVoiceData: 当前语音数据, 编码格式要求为BASE64且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数）。格式要求参考[音频上传格式](https://cloud.tencent.com/document/product/884/56132)
+流式模式下需要将语音数据进行分片处理，参考：[分片大小设置](https://cloud.tencent.com/document/product/884/78985#.E5.88.86.E7.89.87.E5.A4.A7.E5.B0.8F.E8.AE.BE.E7.BD.AE.E4.B8.BA.E5.A4.9A.E5.A4.A7.E6.AF.94.E8.BE.83.E5.90.88.E9.80.82.3F)
+如何进行流式分片参考：[流式评测](https://cloud.tencent.com/document/product/884/78824#.E6.B5.81.E5.BC.8F.E8.AF.84.E6.B5.8B)
         :type UserVoiceData: str
         :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
         :param Keywords: 关键词列表
         :type Keywords: list of Keyword
-        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
+        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。使用指南：[业务应用](https://cloud.tencent.com/document/product/884/78824#.E4.B8.9A.E5.8A.A1.E5.BA.94.E7.94.A8)
         :type SoeAppId: str
         :param IsQuery: 查询标识，当该参数为1时，该请求为查询请求，请求返回该 Session 评估结果。
         :type IsQuery: int
@@ -402,6 +406,15 @@ class SentenceInfo(AbstractModel):
         :type PronCompletion: float
         :param SuggestedScore: 建议评分，取值范围[0,100]，评分方式为建议评分 = 准确度（PronAccuracyfloat）* 完整度（PronCompletionfloat）*（2 - 完整度（PronCompletionfloat）），如若评分策略不符合请参考Words数组中的详细分数自定义评分逻辑。
         :type SuggestedScore: float
+        :param RefTextId: 匹配候选文本的序号，在句子多分支、情景对 话、段落模式下表示匹配到的文本序号
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RefTextId: int
+        :param KeyWordHits: 主题词命中标志，0表示没命中，1表示命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :type KeyWordHits: list of float
+        :param UnKeyWordHits: 负向主题词命中标志，0表示没命中，1表示命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UnKeyWordHits: list of float
         """
         self.SentenceId = None
         self.Words = None
@@ -409,6 +422,9 @@ class SentenceInfo(AbstractModel):
         self.PronFluency = None
         self.PronCompletion = None
         self.SuggestedScore = None
+        self.RefTextId = None
+        self.KeyWordHits = None
+        self.UnKeyWordHits = None
 
 
     def _deserialize(self, params):
@@ -423,6 +439,9 @@ class SentenceInfo(AbstractModel):
         self.PronFluency = params.get("PronFluency")
         self.PronCompletion = params.get("PronCompletion")
         self.SuggestedScore = params.get("SuggestedScore")
+        self.RefTextId = params.get("RefTextId")
+        self.KeyWordHits = params.get("KeyWordHits")
+        self.UnKeyWordHits = params.get("UnKeyWordHits")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -444,21 +463,22 @@ class TransmitOralProcessRequest(AbstractModel):
         :type SeqId: int
         :param IsEnd: 是否传输完毕标志，若为0表示未完毕，若为1则传输完毕开始评估，非流式模式下无意义。
         :type IsEnd: int
-        :param VoiceFileType: 语音文件类型
-1: raw
+        :param VoiceFileType: 1: raw/pcm
 2: wav
 3: mp3
 4: speex
-语音文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败。
+[音频上传格式](https://cloud.tencent.com/document/product/884/56132)
         :type VoiceFileType: int
         :param VoiceEncodeType: 语音编码类型
 1:pcm
         :type VoiceEncodeType: int
-        :param UserVoiceData: 当前数据包数据, 流式模式下数据包大小可以按需设置，在网络稳定时，分片大小建议设置0.5k，且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数），编码格式要求为BASE64。
+        :param UserVoiceData: 当前语音数据, 编码格式要求为BASE64且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数）。格式要求参考[音频上传格式](https://cloud.tencent.com/document/product/884/56132)
+流式模式下需要将语音数据进行分片处理，参考：[分片大小设置](https://cloud.tencent.com/document/product/884/78985#.E5.88.86.E7.89.87.E5.A4.A7.E5.B0.8F.E8.AE.BE.E7.BD.AE.E4.B8.BA.E5.A4.9A.E5.A4.A7.E6.AF.94.E8.BE.83.E5.90.88.E9.80.82.3F)
+如何进行流式分片参考：[流式评测](https://cloud.tencent.com/document/product/884/78824#.E6.B5.81.E5.BC.8F.E8.AF.84.E6.B5.8B)
         :type UserVoiceData: str
         :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
-        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
+        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。使用指南：[业务应用](https://cloud.tencent.com/document/product/884/78824#.E4.B8.9A.E5.8A.A1.E5.BA.94.E7.94.A8)
         :type SoeAppId: str
         :param IsLongLifeSession: 长效session标识，当该参数为1时，session的持续时间为300s，但会一定程度上影响第一个数据包的返回速度。当InitOralProcess接口调用时此项为1时，此项必填1才可生效。
         :type IsLongLifeSession: int
@@ -504,15 +524,15 @@ class TransmitOralProcessResponse(AbstractModel):
         r"""
         :param PronAccuracy: 发音精准度，取值范围[-1, 100]，当取-1时指完全不匹配，当为句子模式时，是所有已识别单词准确度的加权平均值，在reftext中但未识别出来的词不计入分数中。当为流式模式且请求中IsEnd未置1时，取值无意义。
         :type PronAccuracy: float
-        :param PronFluency: 发音流利度，取值范围[0, 1]，当为词模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义
+        :param PronFluency: 发音流利度，取值范围[0, 1]，当为词模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义。取值无意义时，值为-1
         :type PronFluency: float
-        :param PronCompletion: 发音完整度，取值范围[0, 1]，当为词模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义
+        :param PronCompletion: 发音完整度，取值范围[0, 1]，当为词模式或自由说模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义。取值无意义时，值为-1
         :type PronCompletion: float
         :param Words: 详细发音评估结果
         :type Words: list of WordRsp
         :param SessionId: 语音段唯一标识，一段语音一个SessionId
         :type SessionId: str
-        :param AudioUrl: 保存语音音频文件下载地址
+        :param AudioUrl: 已废弃，不再保存语音音频文件下载地址
         :type AudioUrl: str
         :param SentenceInfoSet: 断句中间结果，中间结果是局部最优而非全局最优的结果，所以中间结果有可能和最终整体结果对应部分不一致；中间结果的输出便于客户端UI更新；待用户发音完全结束后，系统会给出一个综合所有句子的整体结果。
         :type SentenceInfoSet: list of SentenceInfo
@@ -520,6 +540,15 @@ class TransmitOralProcessResponse(AbstractModel):
         :type Status: str
         :param SuggestedScore: 建议评分，取值范围[0,100]，评分方式为建议评分 = 准确度（PronAccuracy）× 完整度（PronCompletion）×（2 - 完整度（PronCompletion）），如若评分策略不符合请参考Words数组中的详细分数自定义评分逻辑。
         :type SuggestedScore: float
+        :param RefTextId: 匹配候选文本的序号，在句子多分支、情景对 话、段落模式下表示匹配到的文本序号
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RefTextId: int
+        :param KeyWordHits: 主题词命中标志，0表示没命中，1表示命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :type KeyWordHits: list of float
+        :param UnKeyWordHits: 负向主题词命中标志，0表示没命中，1表示命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UnKeyWordHits: list of float
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -532,6 +561,9 @@ class TransmitOralProcessResponse(AbstractModel):
         self.SentenceInfoSet = None
         self.Status = None
         self.SuggestedScore = None
+        self.RefTextId = None
+        self.KeyWordHits = None
+        self.UnKeyWordHits = None
         self.RequestId = None
 
 
@@ -555,6 +587,9 @@ class TransmitOralProcessResponse(AbstractModel):
                 self.SentenceInfoSet.append(obj)
         self.Status = params.get("Status")
         self.SuggestedScore = params.get("SuggestedScore")
+        self.RefTextId = params.get("RefTextId")
+        self.KeyWordHits = params.get("KeyWordHits")
+        self.UnKeyWordHits = params.get("UnKeyWordHits")
         self.RequestId = params.get("RequestId")
 
 
@@ -571,16 +606,19 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :param IsEnd: 是否传输完毕标志，若为0表示未完毕，若为1则传输完毕开始评估，非流式模式下无意义。
         :type IsEnd: int
         :param VoiceFileType: 语音文件类型
-1: raw
+1: raw/pcm
 2: wav
 3: mp3
 4: speex
 语音文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败。
+[音频上传格式](https://cloud.tencent.com/document/product/884/56132)
         :type VoiceFileType: int
         :param VoiceEncodeType: 语音编码类型
 1:pcm
         :type VoiceEncodeType: int
-        :param UserVoiceData: 当前数据包数据, 流式模式下数据包大小可以按需设置，在网络良好的情况下，建议设置为1k，且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数），编码格式要求为BASE64。
+        :param UserVoiceData: 当前语音数据, 编码格式要求为BASE64且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数）。格式要求参考[音频上传格式](https://cloud.tencent.com/document/product/884/56132)
+流式模式下需要将语音数据进行分片处理，参考：[分片大小设置](https://cloud.tencent.com/document/product/884/78985#.E5.88.86.E7.89.87.E5.A4.A7.E5.B0.8F.E8.AE.BE.E7.BD.AE.E4.B8.BA.E5.A4.9A.E5.A4.A7.E6.AF.94.E8.BE.83.E5.90.88.E9.80.82.3F)
+如何进行流式分片参考：[流式测试](https://cloud.tencent.com/document/product/884/78824#.E6.B5.81.E5.BC.8F.E8.AF.84.E6.B5.8B)
         :type UserVoiceData: str
         :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
@@ -609,34 +647,35 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :param ScoreCoeff: 评价苛刻指数。取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数。
 1.0：适用于最小年龄段用户，一般对应儿童应用场景；
 4.0：适用于最高年龄段用户，一般对应成人严格打分场景。
+苛刻度影响范围参考：[苛刻度影响范围](https://cloud.tencent.com/document/product/884/78824#.E8.8B.9B.E5.88.BB.E5.BA.A6)
         :type ScoreCoeff: float
-        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
+        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。使用指南：[业务应用](https://cloud.tencent.com/document/product/884/78824#.E4.B8.9A.E5.8A.A1.E5.BA.94.E7.94.A8)
         :type SoeAppId: str
         :param StorageMode: 音频存储模式，此参数已废弃，无需设置，设置与否都默认为0不存储；
 注：有存储需求的用户建议自行存储至腾讯云COS[对象存储](https://cloud.tencent.com/product/cos)使用。
         :type StorageMode: int
         :param SentenceInfoEnabled: 输出断句中间结果标识
-0：不输出
+0：不输出（默认）
 1：输出，通过设置该参数
-可以在评估过程中的分片传输请求中，返回已经评估断句的中间结果，中间结果可用于客户端 UI 更新，输出结果为TransmitOralProcess请求返回结果 SentenceInfoSet 字段。
+可以在评估过程中的分片传输请求中，返回已经评估断句的中间结果，中间结果可用于客户端 UI 更新，输出结果为TransmitOralProcessWithInit请求返回结果 SentenceInfoSet 字段。
         :type SentenceInfoEnabled: int
         :param ServerType: 评估语言
-0：英文
+0：英文（默认）
 1：中文
-ServerType不填默认为0
         :type ServerType: int
         :param IsAsync: 异步模式标识
-0：同步模式
-1：异步模式（一般情况不建议使用异步模式）
+0：同步模式（默认）
+1：异步模式（一般情况不建议使用异步模式，如需使用参考：[异步轮询](https://cloud.tencent.com/document/product/884/78824#.E7.BB.93.E6.9E.9C.E6.9F.A5.E8.AF.A2)）
 可选值参考[服务模式](https://cloud.tencent.com/document/product/884/33697)。
         :type IsAsync: int
         :param IsQuery: 查询标识，当该参数为1时，该请求为查询请求，请求返回该 Session 评估结果。
         :type IsQuery: int
         :param TextMode: 输入文本模式
-0: 普通文本
+0: 普通文本（默认）
 1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本
-2：音素注册模式（提工单注册需要使用音素的单词）。
         :type TextMode: int
+        :param Keyword: 主题词和关键词
+        :type Keyword: str
         """
         self.SeqId = None
         self.IsEnd = None
@@ -655,6 +694,7 @@ ServerType不填默认为0
         self.IsAsync = None
         self.IsQuery = None
         self.TextMode = None
+        self.Keyword = None
 
 
     def _deserialize(self, params):
@@ -675,6 +715,7 @@ ServerType不填默认为0
         self.IsAsync = params.get("IsAsync")
         self.IsQuery = params.get("IsQuery")
         self.TextMode = params.get("TextMode")
+        self.Keyword = params.get("Keyword")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -693,15 +734,15 @@ class TransmitOralProcessWithInitResponse(AbstractModel):
         r"""
         :param PronAccuracy: 发音精准度，取值范围[-1, 100]，当取-1时指完全不匹配，当为句子模式时，是所有已识别单词准确度的加权平均值，在reftext中但未识别出来的词不计入分数中。当为流式模式且请求中IsEnd未置1时，取值无意义。
         :type PronAccuracy: float
-        :param PronFluency: 发音流利度，取值范围[0, 1]，当为词模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义
+        :param PronFluency: 发音流利度，取值范围[0, 1]，当为词模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义。取值无意义时，值为-1
         :type PronFluency: float
-        :param PronCompletion: 发音完整度，取值范围[0, 1]，当为词模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义
+        :param PronCompletion: 发音完整度，取值范围[0, 1]，当为词模式或自由说模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义。取值无意义时，值为-1
         :type PronCompletion: float
         :param Words: 详细发音评估结果
         :type Words: list of WordRsp
         :param SessionId: 语音段唯一标识，一段语音一个SessionId
         :type SessionId: str
-        :param AudioUrl: 保存语音音频文件下载地址
+        :param AudioUrl: 已废弃，不再保存语音音频文件下载地址
         :type AudioUrl: str
         :param SentenceInfoSet: 断句中间结果，中间结果是局部最优而非全局最优的结果，所以中间结果有可能和最终整体结果对应部分不一致；中间结果的输出便于客户端UI更新；待用户发音完全结束后，系统会给出一个综合所有句子的整体结果。
         :type SentenceInfoSet: list of SentenceInfo
@@ -709,6 +750,15 @@ class TransmitOralProcessWithInitResponse(AbstractModel):
         :type Status: str
         :param SuggestedScore: 建议评分，取值范围[0,100]，评分方式为建议评分 = 准确度（PronAccuracy）× 完整度（PronCompletion）×（2 - 完整度（PronCompletion）），如若评分策略不符合请参考Words数组中的详细分数自定义评分逻辑。
         :type SuggestedScore: float
+        :param RefTextId: 匹配候选文本的序号，在句子多分支、情景对 话、段落模式下表示匹配到的文本序号
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RefTextId: int
+        :param KeyWordHits: 主题词命中标志，0表示没命中，1表示命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :type KeyWordHits: list of float
+        :param UnKeyWordHits: 负向主题词命中标志，0表示没命中，1表示命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UnKeyWordHits: list of float
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -721,6 +771,9 @@ class TransmitOralProcessWithInitResponse(AbstractModel):
         self.SentenceInfoSet = None
         self.Status = None
         self.SuggestedScore = None
+        self.RefTextId = None
+        self.KeyWordHits = None
+        self.UnKeyWordHits = None
         self.RequestId = None
 
 
@@ -744,6 +797,9 @@ class TransmitOralProcessWithInitResponse(AbstractModel):
                 self.SentenceInfoSet.append(obj)
         self.Status = params.get("Status")
         self.SuggestedScore = params.get("SuggestedScore")
+        self.RefTextId = params.get("RefTextId")
+        self.KeyWordHits = params.get("KeyWordHits")
+        self.UnKeyWordHits = params.get("UnKeyWordHits")
         self.RequestId = params.get("RequestId")
 
 
@@ -770,6 +826,9 @@ class WordRsp(AbstractModel):
         :type PhoneInfos: list of PhoneInfo
         :param ReferenceWord: 参考词，目前为保留字段。
         :type ReferenceWord: str
+        :param KeywordTag: 主题词命中标志，0表示没命中，1表示命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :type KeywordTag: int
         """
         self.MemBeginTime = None
         self.MemEndTime = None
@@ -779,6 +838,7 @@ class WordRsp(AbstractModel):
         self.MatchTag = None
         self.PhoneInfos = None
         self.ReferenceWord = None
+        self.KeywordTag = None
 
 
     def _deserialize(self, params):
@@ -795,6 +855,7 @@ class WordRsp(AbstractModel):
                 obj._deserialize(item)
                 self.PhoneInfos.append(obj)
         self.ReferenceWord = params.get("ReferenceWord")
+        self.KeywordTag = params.get("KeywordTag")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
